==> alipay-sdk-java-4.10.94.DEV-source.jar: com/alipay/api/domain/AlipayPayApplepayTransactionauthtokenCreateModel.java <==
package com.alipay.api.domain;

import java.util.List;

import com.alipay.api.AlipayObject;
import com.alipay.api.internal.mapping.ApiField;
import com.alipay.api.internal.mapping.ApiListField;

/**
 * 注册拉取支付结果的权限authToken
 *
 * @author auto create
 * @since 1.0, 2020-04-03 14:19:59
 */
public class AlipayPayApplepayTransactionauthtokenCreateModel extends AlipayObject {

	private static final long serialVersionUID = 3387841824297246356L;

	/**
	 * 设备id
	 */
	@ApiField("device_identifier")
	private String deviceIdentifier;

	/**
	 * 卡id
	 */
	@ApiField("provisioning_bundle_identifier")
	private String provisioningBundleIdentifier;

	/**
	 * 卡id列表，与卡id两者不能同时为空
	 */
	@ApiListField("provisioning_bundle_identifiers")
	@ApiField("string")
	private List<String> provisioningBundleIdentifiers;

	/**
	 * 推送通知给wagu设备的token
	 */
	@ApiField("push_token")
	private String pushToken;

	/**
	 * uid
	 */
	@ApiField("reference_identifier")
	private String referenceIdentifier;

	public String getDeviceIdentifier() {
		return this.deviceIdentifier;
	}
	public void setDeviceIdentifier(String deviceIdentifier) {
		this.deviceIdentifier = deviceIdentifier;
	}

	public String getProvisioningBundleIdentifier() {
		return this.provisioningBundleIdentifier;
	}
	public void setProvisioningBundleIdentifier(String provisioningBundleIdentifier) {
		this.provisioningBundleIdentifier = provisioningBundleIdentifier;
	}

	public List<String> getProvisioningBundleIdentifiers() {
		return this.provisioningBundleIdentifiers;
	}
	public void setProvisioningBundleIdentifiers(List<String> provisioningBundleIdentifiers) {
		this.provisioningBundleIdentifiers = provisioningBundleIdentifiers;
	}

	public String getPushToken() {
		return this.pushToken;
	}
	public void setPushToken(String pushToken) {
		this.pushToken = pushToken;
	}

	public String getReferenceIdentifier() {
		return this.referenceIdentifier;
	}
	public void setReferenceIdentifier(String referenceIdentifier) {
		this.referenceIdentifier = referenceIdentifier;
	}

}

==> alipay-sdk-java-4.38.22.DEV-source.jar: com/alipay/api/domain/AlipayPayApplepayTransactionauthtokenCreateModel.java <==
package com.alipay.api.domain;

import java.util.List;

import com.alipay.api.AlipayObject;
import com.alipay.api.internal.mapping.ApiField;
import com.alipay.api.internal.mapping.ApiListField;

/**
 * 注册拉取支付结果的权限authToken
 *
 * @author auto create
 * @since 1.0, 2022-11-21 16:36:59
 */
public class AlipayPayApplepayTransactionauthtokenCreateModel extends AlipayObject {

	private static final long serialVersionUID = 3321614348219639616L;

	/**
	 * 设备id
	 */
	@ApiField("device_identifier")
	private String deviceIdentifier;

	/**
	 * uid
	 */
	@ApiField("open_id")
	private String openId;

	/**
	 * 卡id
	 */
	@ApiField("provisioning_bundle_identifier")
	private String provisioningBundleIdentifier;

	/**
	 * 卡id列表，与卡id两者不能同时为空
	 */
	@ApiListField("provisioning_bundle_identifiers")
	@ApiField("string")
	private List<String> provisioningBundleIdentifiers;

	/**
	 * 推送通知给wagu设备的token
	 */
	@ApiField("push_token")
	private String pushToken;

	/**
	 * uid
	 */
	@ApiField("reference_identifier")
	private String referenceIdentifier;

	public String getDeviceIdentifier() {
		return this.deviceIdentifier;
	}
	public void setDeviceIdentifier(String deviceIdentifier) {
		this.deviceIdentifier = deviceIdentifier;
	}

	public String getOpenId() {
		return this.openId;
	}
	public void setOpenId(String openId) {
		this.openId = openId;
	}

	public String getProvisioningBundleIdentifier() {
		return this.provisioningBundleIdentifier;
	}
	public void setProvisioningBundleIdentifier(String provisioningBundleIdentifier) {
		this.provisioningBundleIdentifier = provisioningBundleIdentifier;
	}

	public List<String> getProvisioningBundleIdentifiers() {
		return this.provisioningBundleIdentifiers;
	}
	public void setProvisioningBundleIdentifiers(List<String> provisioningBundleIdentifiers) {
		this.provisioningBundleIdentifiers = provisioningBundleIdentifiers;
	}

	public String getPushToken() {
		return this.pushToken;
	}
	public void setPushToken(String pushToken) {
		this.pushToken = pushToken;
	}

	public String getReferenceIdentifier() {
		return this.referenceIdentifier;
	}
	public void setReferenceIdentifier(String referenceIdentifier) {
		this.referenceIdentifier = referenceIdentifier;
	}

}
